import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:path/path.dart' as p;

/// Teeny icons (1195 icons)
///
/// - build svg for teenyicons icon libraries
/// - constants link to svg icon resources
class Teenyicons extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const Teenyicons(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  static Widget svgAsset(String assetName,
      {Key? key,
      bool matchTextDirection = false,
      AssetBundle? bundle,
      String? package,
      double? width,
      double? height,
      BoxFit fit = BoxFit.contain,
      AlignmentGeometry alignment = Alignment.center,
      bool allowDrawingOutsideViewBox = false,
      WidgetBuilder? placeholderBuilder,
      Color? color,
      BlendMode colorBlendMode = BlendMode.srcIn,
      String? semanticsLabel,
      bool excludeFromSemantics = false,
      Clip clipBehavior = Clip.hardEdge,
      bool cacheColorFilter = false,
      SvgTheme? theme}) {
    final path = p.join(
      // external library
      'packages/iconforest_teenyicons/assets/images/teenyicons/',
      // local library
      // 'assets/images/teenyicons/',
      assetName,
    );
    return SvgPicture.asset(
      path,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  @override
  Widget build(BuildContext context) {
    return svgAsset(
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String $360_outline = '360_outline.svg';
  static const String $360_solid = '360_solid.svg';
  static const String ab_testing_outline = 'ab_testing_outline.svg';
  static const String ab_testing_solid = 'ab_testing_solid.svg';
  static const String add_outline = 'add_outline.svg';
  static const String add_small_outline = 'add_small_outline.svg';
  static const String add_small_solid = 'add_small_solid.svg';
  static const String add_solid = 'add_solid.svg';
  static const String address_book_outline = 'address_book_outline.svg';
  static const String address_book_solid = 'address_book_solid.svg';
  static const String adjust_horizontal_alt_outline = 'adjust_horizontal_alt_outline.svg';
  static const String adjust_horizontal_alt_solid = 'adjust_horizontal_alt_solid.svg';
  static const String adjust_horizontal_outline = 'adjust_horizontal_outline.svg';
  static const String adjust_horizontal_solid = 'adjust_horizontal_solid.svg';
  static const String adjust_vertical_alt_outline = 'adjust_vertical_alt_outline.svg';
  static const String adjust_vertical_alt_solid = 'adjust_vertical_alt_solid.svg';
  static const String adjust_vertical_outline = 'adjust_vertical_outline.svg';
  static const String adjust_vertical_solid = 'adjust_vertical_solid.svg';
  static const String airplay_outline = 'airplay_outline.svg';
  static const String airplay_solid = 'airplay_solid.svg';
  static const String airpods_outline = 'airpods_outline.svg';
  static const String airpods_solid = 'airpods_solid.svg';
  static const String alarm_outline = 'alarm_outline.svg';
  static const String alarm_solid = 'alarm_solid.svg';
  static const String alien_outline = 'alien_outline.svg';
  static const String alien_solid = 'alien_solid.svg';
  static const String align_bottom_outline = 'align_bottom_outline.svg';
  static const String align_bottom_solid = 'align_bottom_solid.svg';
  static const String align_center_horizontal_outline = 'align_center_horizontal_outline.svg';
  static const String align_center_horizontal_solid = 'align_center_horizontal_solid.svg';
  static const String align_center_vertical_outline = 'align_center_vertical_outline.svg';
  static const String align_center_vertical_solid = 'align_center_vertical_solid.svg';
  static const String align_left_solid = 'align_left_solid.svg';
  static const String align_left = 'align_left.svg';
  static const String align_right_outline = 'align_right_outline.svg';
  static const String align_right_solid = 'align_right_solid.svg';
  static const String align_text_center_outline = 'align_text_center_outline.svg';
  static const String align_text_center_solid = 'align_text_center_solid.svg';
  static const String align_text_justify_outline = 'align_text_justify_outline.svg';
  static const String align_text_justify_solid = 'align_text_justify_solid.svg';
  static const String align_text_left_solid = 'align_text_left_solid.svg';
  static const String align_text_left = 'align_text_left.svg';
  static const String align_text_right_outline = 'align_text_right_outline.svg';
  static const String align_text_right_solid = 'align_text_right_solid.svg';
  static const String align_top_solid = 'align_top_solid.svg';
  static const String align_top = 'align_top.svg';
  static const String anchor_outline = 'anchor_outline.svg';
  static const String anchor_solid = 'anchor_solid.svg';
  static const String android_outline = 'android_outline.svg';
  static const String android_solid = 'android_solid.svg';
  static const String angular_outline = 'angular_outline.svg';
  static const String angular_solid = 'angular_solid.svg';
  static const String anja_outline = 'anja_outline.svg';
  static const String anja_solid = 'anja_solid.svg';
  static const String anti_clockwise_outline = 'anti_clockwise_outline.svg';
  static const String anti_clockwise_solid = 'anti_clockwise_solid.svg';
  static const String apple_outline = 'apple_outline.svg';
  static const String apple_solid = 'apple_solid.svg';
  static const String appointments_outline = 'appointments_outline.svg';
  static const String appointments_solid = 'appointments_solid.svg';
  static const String archive_outline = 'archive_outline.svg';
  static const String archive_solid = 'archive_solid.svg';
  static const String area_chart_alt_outline = 'area_chart_alt_outline.svg';
  static const String area_chart_alt_solid = 'area_chart_alt_solid.svg';
  static const String area_chart_outline = 'area_chart_outline.svg';
  static const String area_chart_solid = 'area_chart_solid.svg';
  static const String arrow_down_circle_outline = 'arrow_down_circle_outline.svg';
  static const String arrow_down_circle_solid = 'arrow_down_circle_solid.svg';
  static const String arrow_down_outline = 'arrow_down_outline.svg';
  static const String arrow_down_small_outline = 'arrow_down_small_outline.svg';
  static const String arrow_down_small_solid = 'arrow_down_small_solid.svg';
  static const String arrow_down_solid = 'arrow_down_solid.svg';
  static const String arrow_left_circle_outline = 'arrow_left_circle_outline.svg';
  static const String arrow_left_circle_solid = 'arrow_left_circle_solid.svg';
  static const String arrow_left_outline = 'arrow_left_outline.svg';
  static const String arrow_left_small_outline = 'arrow_left_small_outline.svg';
  static const String arrow_left_small_solid = 'arrow_left_small_solid.svg';
  static const String arrow_left_solid = 'arrow_left_solid.svg';
  static const String arrow_outline = 'arrow_outline.svg';
  static const String arrow_right_circle_outline = 'arrow_right_circle_outline.svg';
  static const String arrow_right_circle_solid = 'arrow_right_circle_solid.svg';
  static const String arrow_right_outline = 'arrow_right_outline.svg';
  static const String arrow_right_small_outline = 'arrow_right_small_outline.svg';
  static const String arrow_right_small_solid = 'arrow_right_small_solid.svg';
  static const String arrow_right_solid = 'arrow_right_solid.svg';
  static const String arrow_solid = 'arrow_solid.svg';
  static const String arrow_up_circle_outline = 'arrow_up_circle_outline.svg';
  static const String arrow_up_circle_solid = 'arrow_up_circle_solid.svg';
  static const String arrow_up_outline = 'arrow_up_outline.svg';
  static const String arrow_up_small_outline = 'arrow_up_small_outline.svg';
  static const String arrow_up_small_solid = 'arrow_up_small_solid.svg';
  static const String arrow_up_solid = 'arrow_up_solid.svg';
  static const String artboard_outline = 'artboard_outline.svg';
  static const String artboard_solid = 'artboard_solid.svg';
  static const String at_outline = 'at_outline.svg';
  static const String at_solid = 'at_solid.svg';
  static const String attach_outline = 'attach_outline.svg';
  static const String attach_solid = 'attach_solid.svg';
  static const String attachment_outline = 'attachment_outline.svg';
  static const String attachment_solid = 'attachment_solid.svg';
  static const String audio_cable_outline = 'audio_cable_outline.svg';
  static const String audio_cable_solid = 'audio_cable_solid.svg';
  static const String audio_document_outline = 'audio_document_outline.svg';
  static const String audio_document_solid = 'audio_document_solid.svg';
  static const String azure_outline = 'azure_outline.svg';
  static const String azure_solid = 'azure_solid.svg';
  static const String backspace_outline = 'backspace_outline.svg';
  static const String backspace_solid = 'backspace_solid.svg';
  static const String bag_alt_outline = 'bag_alt_outline.svg';
  static const String bag_minus_outline = 'bag_minus_outline.svg';
  static const String bag_outline = 'bag_outline.svg';
  static const String bag_plus_outline = 'bag_plus_outline.svg';
  static const String bag_plus_solid = 'bag_plus_solid.svg';
  static const String bag_solid = 'bag_solid.svg';
  static const String bank_outline = 'bank_outline.svg';
  static const String bank_solid = 'bank_solid.svg';
  static const String bar_chart_outline = 'bar_chart_outline.svg';
  static const String barcode_outline = 'barcode_outline.svg';
  static const String barcode_solid = 'barcode_solid.svg';
  static const String basket_minus_outline = 'basket_minus_outline.svg';
  static const String basket_minus_solid = 'basket_minus_solid.svg';
  static const String basket_outline = 'basket_outline.svg';
  static const String basket_plus_outline = 'basket_plus_outline.svg';
  static const String basket_plus_solid = 'basket_plus_solid.svg';
  static const String basket_solid = 'basket_solid.svg';
  static const String bath_outline = 'bath_outline.svg';
  static const String bath_solid = 'bath_solid.svg';
  static const String battery_0_outline = 'battery_0_outline.svg';
  static const String battery_0_solid = 'battery_0_solid.svg';
  static const String battery_1_outline = 'battery_1_outline.svg';
  static const String battery_1_solid = 'battery_1_solid.svg';
  static const String battery_2_outline = 'battery_2_outline.svg';
  static const String battery_2_solid = 'battery_2_solid.svg';
  static const String battery_3_outline = 'battery_3_outline.svg';
  static const String battery_3_solid = 'battery_3_solid.svg';
  static const String battery_4_outline = 'battery_4_outline.svg';
  static const String battery_4_solid = 'battery_4_solid.svg';
  static const String battery_5_outline = 'battery_5_outline.svg';
  static const String battery_5_solid = 'battery_5_solid.svg';
  static const String battery_charge_outline = 'battery_charge_outline.svg';
  static const String battery_charge_solid = 'battery_charge_solid.svg';
  static const String bed_double_outline = 'bed_double_outline.svg';
  static const String bed_double_solid = 'bed_double_solid.svg';
  static const String bed_single_outline = 'bed_single_outline.svg';
  static const String bed_single_solid = 'bed_single_solid.svg';
  static const String behance_outline = 'behance_outline.svg';
  static const String behance_solid = 'behance_solid.svg';
  static const String bell_outline = 'bell_outline.svg';
  static const String bell_solid = 'bell_solid.svg';
  static const String bin_outline = 'bin_outline.svg';
  static const String bin_solid = 'bin_solid.svg';
  static const String bitbucket_outline = 'bitbucket_outline.svg';
  static const String bitbucket_solid = 'bitbucket_solid.svg';
  static const String bitcoin_outline = 'bitcoin_outline.svg';
  static const String bitcoin_solid = 'bitcoin_solid.svg';
  static const String bluetooth_outline = 'bluetooth_outline.svg';
  static const String bluetooth_solid = 'bluetooth_solid.svg';
  static const String bold_outline = 'bold_outline.svg';
  static const String bold_solid = 'bold_solid.svg';
  static const String book_outline = 'book_outline.svg';
  static const String book_solid = 'book_solid.svg';
  static const String bookmark_outline = 'bookmark_outline.svg';
  static const String bookmark_solid = 'bookmark_solid.svg';
  static const String border_all_outline = 'border_all_outline.svg';
  static const String border_all_solid = 'border_all_solid.svg';
  static const String border_bottom_outline = 'border_bottom_outline.svg';
  static const String border_bottom_solid = 'border_bottom_solid.svg';
  static const String border_horizontal_outline = 'border_horizontal_outline.svg';
  static const String border_horizontal_solid = 'border_horizontal_solid.svg';
  static const String border_inner_outline = 'border_inner_outline.svg';
  static const String border_inner_solid = 'border_inner_solid.svg';
  static const String border_left_outline = 'border_left_outline.svg';
  static const String border_left_solid = 'border_left_solid.svg';
  static const String border_none_outline = 'border_none_outline.svg';
  static const String border_none_solid = 'border_none_solid.svg';
  static const String border_outer_outline = 'border_outer_outline.svg';
  static const String border_outer_solid = 'border_outer_solid.svg';
  static const String border_radius_outline = 'border_radius_outline.svg';
  static const String border_radius_solid = 'border_radius_solid.svg';
  static const String border_right_outline = 'border_right_outline.svg';
  static const String border_right_solid = 'border_right_solid.svg';
  static const String border_top_outline = 'border_top_outline.svg';
  static const String border_top_solid = 'border_top_solid.svg';
  static const String border_vertical_outline = 'border_vertical_outline.svg';
  static const String border_vertical_solid = 'border_vertical_solid.svg';
  static const String bottom_left_outline = 'bottom_left_outline.svg';
  static const String bottom_left_solid = 'bottom_left_solid.svg';
  static const String bottom_right_outline = 'bottom_right_outline.svg';
  static const String bottom_right_solid = 'bottom_right_solid.svg';
  static const String box_outline = 'box_outline.svg';
  static const String box_solid = 'box_solid.svg';
  static const String bracket_outline = 'bracket_outline.svg';
  static const String bracket_solid = 'bracket_solid.svg';
  static const String briefcase_alt_outline = 'briefcase_alt_outline.svg';
  static const String briefcase_alt_solid = 'briefcase_alt_solid.svg';
  static const String briefcase_outline = 'briefcase_outline.svg';
  static const String briefcase_solid = 'briefcase_solid.svg';
  static const String brush_outline = 'brush_outline.svg';
  static const String brush_solid = 'brush_solid.svg';
  static const String bug_outline = 'bug_outline.svg';
  static const String bug_solid = 'bug_solid.svg';
  static const String building_outline = 'building_outline.svg';
  static const String building_solid = 'building_solid.svg';
  static const String bulb_off_outline = 'bulb_off_outline.svg';
  static const String bulb_off_solid = 'bulb_off_solid.svg';
  static const String bulb_on_outline = 'bulb_on_outline.svg';
  static const String bulb_on_solid = 'bulb_on_solid.svg';
  static const String button_outline = 'button_outline.svg';
  static const String button_solid = 'button_solid.svg';
  static const String c_outline = 'c_outline.svg';
  static const String c_sharp_outline = 'c_sharp_outline.svg';
  static const String c_sharp_solid = 'c_sharp_solid.svg';
  static const String c_solid = 'c_solid.svg';
  static const String calculator_outline = 'calculator_outline.svg';
  static const String calculator_solid = 'calculator_solid.svg';
  static const String calendar_minus_outline = 'calendar_minus_outline.svg';
  static const String calendar_minus_solid = 'calendar_minus_solid.svg';
  static const String calendar_no_access_outline = 'calendar_no_access_outline.svg';
  static const String calendar_no_access_solid = 'calendar_no_access_solid.svg';
  static const String calendar_outline = 'calendar_outline.svg';
  static const String calendar_plus_outline = 'calendar_plus_outline.svg';
  static const String calendar_plus_solid = 'calendar_plus_solid.svg';
  static const String calendar_solid = 'calendar_solid.svg';
  static const String calendar_tick_outline = 'calendar_tick_outline.svg';
  static const String calendar_tick_solid = 'calendar_tick_solid.svg';
  static const String calendar_x_outline = 'calendar_x_outline.svg';
  static const String calendar_x_solid = 'calendar_x_solid.svg';
  static const String camera_outline = 'camera_outline.svg';
  static const String camera_solid = 'camera_solid.svg';
  static const String candle_chart_outline = 'candle_chart_outline.svg';
  static const String candle_chart_solid = 'candle_chart_solid.svg';
  static const String car_outline = 'car_outline.svg';
  static const String car_solid = 'car_solid.svg';
  static const String caret_vertical_circle_outline = 'caret_vertical_circle_outline.svg';
  static const String caret_vertical_circle_solid = 'caret_vertical_circle_solid.svg';
  static const String caret_vertical_outline = 'caret_vertical_outline.svg';
  static const String caret_vertical_small_outline = 'caret_vertical_small_outline.svg';
  static const String caret_vertical_small_solid = 'caret_vertical_small_solid.svg';
  static const String caret_vertical_solid = 'caret_vertical_solid.svg';
  static const String cart_minus_outline = 'cart_minus_outline.svg';
  static const String cart_minus_solid = 'cart_minus_solid.svg';
  static const String cart_outline = 'cart_outline.svg';
  static const String cart_plus_outline = 'cart_plus_outline.svg';
  static const String cart_plus_solid = 'cart_plus_solid.svg';
  static const String cart_solid = 'cart_solid.svg';
  static const String certificate_outline = 'certificate_outline.svg';
  static const String certificate_solid = 'certificate_solid.svg';
  static const String chat_outline = 'chat_outline.svg';
  static const String chat_solid = 'chat_solid.svg';
  static const String chat_typing_alt_outline = 'chat_typing_alt_outline.svg';
  static const String chat_typing_alt_solid = 'chat_typing_alt_solid.svg';
  static const String chat_typing_outline = 'chat_typing_outline.svg';
  static const String chat_typing_solid = 'chat_typing_solid.svg';
  static const String chatbot_outline = 'chatbot_outline.svg';
  static const String chatbot_solid = 'chatbot_solid.svg';
  static const String chrome_outline = 'chrome_outline.svg';
  static const String chrome_solid = 'chrome_solid.svg';
  static const String church_outline = 'church_outline.svg';
  static const String church_solid = 'church_solid.svg';
  static const String circle_outline = 'circle_outline.svg';
  static const String circle_solid = 'circle_solid.svg';
  static const String clipboard_minus_outline = 'clipboard_minus_outline.svg';
  static const String clipboard_minus_solid = 'clipboard_minus_solid.svg';
  static const String clipboard_no_access_outline = 'clipboard_no_access_outline.svg';
  static const String clipboard_no_access_solid = 'clipboard_no_access_solid.svg';
  static const String clipboard_outline = 'clipboard_outline.svg';
  static const String clipboard_plus_outline = 'clipboard_plus_outline.svg';
  static const String clipboard_plus_solid = 'clipboard_plus_solid.svg';
  static const String clipboard_solid = 'clipboard_solid.svg';
  static const String clipboard_tick_outline = 'clipboard_tick_outline.svg';
  static const String clipboard_tick_solid = 'clipboard_tick_solid.svg';
  static const String clipboard_x_outline = 'clipboard_x_outline.svg';
  static const String clipboard_x_solid = 'clipboard_x_solid.svg';
  static const String clock_outline = 'clock_outline.svg';
  static const String clock_solid = 'clock_solid.svg';
  static const String clockwise_outline = 'clockwise_outline.svg';
  static const String clockwise_solid = 'clockwise_solid.svg';
  static const String code_outline = 'code_outline.svg';
  static const String code_solid = 'code_solid.svg';
  static const String codepen_outline = 'codepen_outline.svg';
  static const String codepen_solid = 'codepen_solid.svg';
  static const String cog_outline = 'cog_outline.svg';
  static const String cog_solid = 'cog_solid.svg';
  static const String compass_outline = 'compass_outline.svg';
  static const String compass_solid = 'compass_solid.svg';
  static const String computer_outline = 'computer_outline.svg';
  static const String computer_solid = 'computer_solid.svg';
  static const String contact_outline = 'contact_outline.svg';
  static const String contact_solid = 'contact_solid.svg';
  static const String contract_outline = 'contract_outline.svg';
  static const String contract_solid = 'contract_solid.svg';
  static const String cost_estimate_outline = 'cost_estimate_outline.svg';
  static const String cost_estimate_solid = 'cost_estimate_solid.svg';
  static const String cplusplus_outline = 'cplusplus_outline.svg';
  static const String cplusplus_solid = 'cplusplus_solid.svg';
  static const String credit_card_outline = 'credit_card_outline.svg';
  static const String credit_card_solid = 'credit_card_solid.svg';
  static const String crop_outline = 'crop_outline.svg';
  static const String crop_solid = 'crop_solid.svg';
  static const String css3_outline = 'css3_outline.svg';
  static const String css3_solid = 'css3_solid.svg';
  static const String csv_outline = 'csv_outline.svg';
  static const String csv_solid = 'csv_solid.svg';
  static const String cup_outline = 'cup_outline.svg';
  static const String cup_solid = 'cup_solid.svg';
  static const String curved_connector_outline = 'curved_connector_outline.svg';
  static const String curved_connector_solid = 'curved_connector_solid.svg';
  static const String d3_outline = 'd3_outline.svg';
  static const String d3_solid = 'd3_solid.svg';
  static const String database_outline = 'database_outline.svg';
  static const String database_solid = 'database_solid.svg';
  static const String denied_outline = 'denied_outline.svg';
  static const String denied_solid = 'denied_solid.svg';
  static const String deno_outline = 'deno_outline.svg';
  static const String deno_solid = 'deno_solid.svg';
  static const String depth_chart_outline = 'depth_chart_outline.svg';
  static const String depth_chart_solid = 'depth_chart_solid.svg';
  static const String desklamp_outline = 'desklamp_outline.svg';
  static const String desklamp_solid = 'desklamp_solid.svg';
  static const String diamond_outline = 'diamond_outline.svg';
  static const String diamond_solid = 'diamond_solid.svg';
  static const String direction_outline = 'direction_outline.svg';
  static const String direction_solid = 'direction_solid.svg';
  static const String discord_outline = 'discord_outline.svg';
  static const String discord_solid = 'discord_solid.svg';
  static const String discount_outline = 'discount_outline.svg';
  static const String discount_solid = 'discount_solid.svg';
  static const String distribute_horizontal_outline = 'distribute_horizontal_outline.svg';
  static const String distribute_horizontal_solid = 'distribute_horizontal_solid.svg';
  static const String distribute_vertical_outline = 'distribute_vertical_outline.svg';
  static const String distribute_vertical_solid = 'distribute_vertical_solid.svg';
  static const String divider_line_outline = 'divider_line_outline.svg';
  static const String divider_line_solid = 'divider_line_solid.svg';
  static const String doc_outline = 'doc_outline.svg';
  static const String doc_solid = 'doc_solid.svg';
  static const String docker_outline = 'docker_outline.svg';
  static const String docker_solid = 'docker_solid.svg';
  static const String documents_outline = 'documents_outline.svg';
  static const String documents_solid = 'documents_solid.svg';
  static const String dollar_outline = 'dollar_outline.svg';
  static const String dollar_solid = 'dollar_solid.svg';
  static const String donut_chart_outline = 'donut_chart_outline.svg';
  static const String donut_chart_solid = 'donut_chart_solid.svg';
  static const String double_caret_down_circle_outline = 'double_caret_down_circle_outline.svg';
  static const String double_caret_down_circle_solid = 'double_caret_down_circle_solid.svg';
  static const String double_caret_down_outline = 'double_caret_down_outline.svg';
  static const String double_caret_down_small_outline = 'double_caret_down_small_outline.svg';
  static const String double_caret_down_small_solid = 'double_caret_down_small_solid.svg';
  static const String double_caret_down_solid = 'double_caret_down_solid.svg';
  static const String double_caret_left_circle_outline = 'double_caret_left_circle_outline.svg';
  static const String double_caret_left_circle_solid = 'double_caret_left_circle_solid.svg';
  static const String double_caret_left_outline = 'double_caret_left_outline.svg';
  static const String double_caret_left_small_outline = 'double_caret_left_small_outline.svg';
  static const String double_caret_left_small_solid = 'double_caret_left_small_solid.svg';
  static const String double_caret_left_solid = 'double_caret_left_solid.svg';
  static const String double_caret_right_circle_outline = 'double_caret_right_circle_outline.svg';
  static const String double_caret_right_circle_solid = 'double_caret_right_circle_solid.svg';
  static const String double_caret_right_outline = 'double_caret_right_outline.svg';
  static const String double_caret_right_small_outline = 'double_caret_right_small_outline.svg';
  static const String double_caret_right_small_solid = 'double_caret_right_small_solid.svg';
  static const String double_caret_right_solid = 'double_caret_right_solid.svg';
  static const String double_caret_up_circle_outline = 'double_caret_up_circle_outline.svg';
  static const String double_caret_up_circle_solid = 'double_caret_up_circle_solid.svg';
  static const String double_caret_up_outline = 'double_caret_up_outline.svg';
  static const String double_caret_up_small_outline = 'double_caret_up_small_outline.svg';
  static const String double_caret_up_small_solid = 'double_caret_up_small_solid.svg';
  static const String double_caret_up_solid = 'double_caret_up_solid.svg';
  static const String down_circle_outline = 'down_circle_outline.svg';
  static const String down_circle_solid = 'down_circle_solid.svg';
  static const String down_outline = 'down_outline.svg';
  static const String down_small_outline = 'down_small_outline.svg';
  static const String down_small_solid = 'down_small_solid.svg';
  static const String down_solid = 'down_solid.svg';
  static const String download_outline = 'download_outline.svg';
  static const String download_solid = 'download_solid.svg';
  static const String drag_horizontal_outline = 'drag_horizontal_outline.svg';
  static const String drag_horizontal_solid = 'drag_horizontal_solid.svg';
  static const String drag_outline = 'drag_outline.svg';
  static const String drag_solid = 'drag_solid.svg';
  static const String drag_vertical_outline = 'drag_vertical_outline.svg';
  static const String drag_vertical_solid = 'drag_vertical_solid.svg';
  static const String dribbble_outline = 'dribbble_outline.svg';
  static const String dribbble_solid = 'dribbble_solid.svg';
  static const String drop_outline = 'drop_outline.svg';
  static const String drop_solid = 'drop_solid.svg';
  static const String dropper_outline = 'dropper_outline.svg';
  static const String dropper_solid = 'dropper_solid.svg';
  static const String edge_outline = 'edge_outline.svg';
  static const String edge_solid = 'edge_solid.svg';
  static const String edit_1_outline = 'edit_1_outline.svg';
  static const String edit_1_solid = 'edit_1_solid.svg';
  static const String edit_circle_outline = 'edit_circle_outline.svg';
  static const String edit_circle_solid = 'edit_circle_solid.svg';
  static const String edit_outline = 'edit_outline.svg';
  static const String edit_small_outline = 'edit_small_outline.svg';
  static const String edit_small_solid = 'edit_small_solid.svg';
  static const String edit_solid = 'edit_solid.svg';
  static const String elbow_connector_outline = 'elbow_connector_outline.svg';
  static const String elbow_connector_solid = 'elbow_connector_solid.svg';
  static const String envelope_open_outline = 'envelope_open_outline.svg';
  static const String envelope_open_solid = 'envelope_open_solid.svg';
  static const String envelope_outline = 'envelope_outline.svg';
  static const String envelope_solid = 'envelope_solid.svg';
  static const String eps_outline = 'eps_outline.svg';
  static const String eps_solid = 'eps_solid.svg';
  static const String eslint_outline = 'eslint_outline.svg';
  static const String eslint_solid = 'eslint_solid.svg';
  static const String ethereum_outline = 'ethereum_outline.svg';
  static const String ethereum_solid = 'ethereum_solid.svg';
  static const String euro_outline = 'euro_outline.svg';
  static const String euro_solid = 'euro_solid.svg';
  static const String exclamation_circle_outline = 'exclamation_circle_outline.svg';
  static const String exclamation_circle_solid = 'exclamation_circle_solid.svg';
  static const String exclamation_outline = 'exclamation_outline.svg';
  static const String exclamation_small_outline = 'exclamation_small_outline.svg';
  static const String exclamation_small_solid = 'exclamation_small_solid.svg';
  static const String exclamation_solid = 'exclamation_solid.svg';
  static const String expand_alt_outline = 'expand_alt_outline.svg';
  static const String expand_alt_solid = 'expand_alt_solid.svg';
  static const String expand_outline = 'expand_outline.svg';
  static const String expand_solid = 'expand_solid.svg';
  static const String eye_closed_outline = 'eye_closed_outline.svg';
  static const String eye_closed_solid = 'eye_closed_solid.svg';
  static const String eye_outline = 'eye_outline.svg';
  static const String eye_solid = 'eye_solid.svg';
  static const String face_id_outline = 'face_id_outline.svg';
  static const String face_id_solid = 'face_id_solid.svg';
  static const String facebook_outline = 'facebook_outline.svg';
  static const String facebook_solid = 'facebook_solid.svg';
  static const String figma_outline = 'figma_outline.svg';
  static const String figma_solid = 'figma_solid.svg';
  static const String file_minus_outline = 'file_minus_outline.svg';
  static const String file_minus_solid = 'file_minus_solid.svg';
  static const String file_no_access_outline = 'file_no_access_outline.svg';
  static const String file_no_access_solid = 'file_no_access_solid.svg';
  static const String file_outline = 'file_outline.svg';
  static const String file_plus_outline = 'file_plus_outline.svg';
  static const String file_plus_solid = 'file_plus_solid.svg';
  static const String file_solid = 'file_solid.svg';
  static const String file_tick_outline = 'file_tick_outline.svg';
  static const String file_tick_solid = 'file_tick_solid.svg';
  static const String file_x_outline = 'file_x_outline.svg';
  static const String file_x_solid = 'file_x_solid.svg';
  static const String filter_outline = 'filter_outline.svg';
  static const String filter_solid = 'filter_solid.svg';
  static const String fingerprint_outline = 'fingerprint_outline.svg';
  static const String fingerprint_solid = 'fingerprint_solid.svg';
  static const String firebase_outline = 'firebase_outline.svg';
  static const String firebase_solid = 'firebase_solid.svg';
  static const String flag_alt_outline = 'flag_alt_outline.svg';
  static const String flag_alt_solid = 'flag_alt_solid.svg';
  static const String flag_outline = 'flag_outline.svg';
  static const String flag_solid = 'flag_solid.svg';
  static const String flip_horizontal_outline = 'flip_horizontal_outline.svg';
  static const String flip_horizontal_solid = 'flip_horizontal_solid.svg';
  static const String flip_vertical_outline = 'flip_vertical_outline.svg';
  static const String flip_vertical_solid = 'flip_vertical_solid.svg';
  static const String float_center_outline = 'float_center_outline.svg';
  static const String float_center_solid = 'float_center_solid.svg';
  static const String float_left_outline = 'float_left_outline.svg';
  static const String float_left_solid = 'float_left_solid.svg';
  static const String float_right_outline = 'float_right_outline.svg';
  static const String float_right_solid = 'float_right_solid.svg';
  static const String floorplan_outline = 'floorplan_outline.svg';
  static const String floorplan_solid = 'floorplan_solid.svg';
  static const String folder_minus_outline = 'folder_minus_outline.svg';
  static const String folder_minus_solid = 'folder_minus_solid.svg';
  static const String folder_no_access_outline = 'folder_no_access_outline.svg';
  static const String folder_no_access_solid = 'folder_no_access_solid.svg';
  static const String folder_outline = 'folder_outline.svg';
  static const String folder_plus_outline = 'folder_plus_outline.svg';
  static const String folder_plus_solid = 'folder_plus_solid.svg';
  static const String folder_solid = 'folder_solid.svg';
  static const String folder_tick_outline = 'folder_tick_outline.svg';
  static const String folder_tick_solid = 'folder_tick_solid.svg';
  static const String folder_x_outline = 'folder_x_outline.svg';
  static const String folder_x_solid = 'folder_x_solid.svg';
  static const String folders_outline = 'folders_outline.svg';
  static const String folders_solid = 'folders_solid.svg';
  static const String forward_circle_outline = 'forward_circle_outline.svg';
  static const String forward_circle_solid = 'forward_circle_solid.svg';
  static const String forward_outline = 'forward_outline.svg';
  static const String forward_small_outline = 'forward_small_outline.svg';
  static const String forward_small_solid = 'forward_small_solid.svg';
  static const String forward_solid = 'forward_solid.svg';
  static const String frame_outline = 'frame_outline.svg';
  static const String frame_solid = 'frame_solid.svg';
  static const String framer_outline = 'framer_outline.svg';
  static const String framer_solid = 'framer_solid.svg';
  static const String game_controller_outline = 'game_controller_outline.svg';
  static const String game_controller_retro_outline = 'game_controller_retro_outline.svg';
  static const String game_controller_retro_solid = 'game_controller_retro_solid.svg';
  static const String game_controller_solid = 'game_controller_solid.svg';
  static const String gantt_chart_outline = 'gantt_chart_outline.svg';
  static const String gantt_chart_solid = 'gantt_chart_solid.svg';
  static const String garage_outline = 'garage_outline.svg';
  static const String garage_solid = 'garage_solid.svg';
  static const String gatsbyjs_outline = 'gatsbyjs_outline.svg';
  static const String gatsbyjs_solid = 'gatsbyjs_solid.svg';
  static const String gba_outline = 'gba_outline.svg';
  static const String gba_solid = 'gba_solid.svg';
  static const String gbc_outline = 'gbc_outline.svg';
  static const String gbc_solid = 'gbc_solid.svg';
  static const String ghost_outline = 'ghost_outline.svg';
  static const String ghost_solid = 'ghost_solid.svg';
  static const String gif_outline = 'gif_outline.svg';
  static const String gif_solid = 'gif_solid.svg';
  static const String gift_outline = 'gift_outline.svg';
  static const String gift_solid = 'gift_solid.svg';
  static const String git_branch_outline = 'git_branch_outline.svg';
  static const String git_branch_solid = 'git_branch_solid.svg';
  static const String git_commit_outline = 'git_commit_outline.svg';
  static const String git_commit_solid = 'git_commit_solid.svg';
  static const String git_compare_outline = 'git_compare_outline.svg';
  static const String git_compare_solid = 'git_compare_solid.svg';
  static const String git_fork_outline = 'git_fork_outline.svg';
  static const String git_fork_solid = 'git_fork_solid.svg';
  static const String git_merge_outline = 'git_merge_outline.svg';
  static const String git_merge_solid = 'git_merge_solid.svg';
  static const String git_outline = 'git_outline.svg';
  static const String git_pull_outline = 'git_pull_outline.svg';
  static const String git_pull_solid = 'git_pull_solid.svg';
  static const String git_solid = 'git_solid.svg';
  static const String github_outline = 'github_outline.svg';
  static const String github_solid = 'github_solid.svg';
  static const String gitlab_outline = 'gitlab_outline.svg';
  static const String gitlab_solid = 'gitlab_solid.svg';
  static const String globe_africa_outline = 'globe_africa_outline.svg';
  static const String globe_africa_solid = 'globe_africa_solid.svg';
  static const String globe_americas_outline = 'globe_americas_outline.svg';
  static const String globe_americas_solid = 'globe_americas_solid.svg';
  static const String globe_outline = 'globe_outline.svg';
  static const String globe_solid = 'globe_solid.svg';
  static const String google_ad_outline = 'google_ad_outline.svg';
  static const String google_ad_solid = 'google_ad_solid.svg';
  static const String google_drive_outline = 'google_drive_outline.svg';
  static const String google_drive_solid = 'google_drive_solid.svg';
  static const String google_outline = 'google_outline.svg';
  static const String google_play_store_outline = 'google_play_store_outline.svg';
  static const String google_play_store_solid = 'google_play_store_solid.svg';
  static const String google_solid = 'google_solid.svg';
  static const String google_streetview_outline = 'google_streetview_outline.svg';
  static const String google_streetview_solid = 'google_streetview_solid.svg';
  static const String graphql_outline = 'graphql_outline.svg';
  static const String graphql_solid = 'graphql_solid.svg';
  static const String grid_layout_outline = 'grid_layout_outline.svg';
  static const String grid_layout_solid = 'grid_layout_solid.svg';
  static const String hashtag_outline = 'hashtag_outline.svg';
  static const String hashtag_solid = 'hashtag_solid.svg';
  static const String hd_screen_outline = 'hd_screen_outline.svg';
  static const String hd_screen_solid = 'hd_screen_solid.svg';
  static const String hdmi_cable_outline = 'hdmi_cable_outline.svg';
  static const String hdmi_cable_solid = 'hdmi_cable_solid.svg';
  static const String headphones_outline = 'headphones_outline.svg';
  static const String headphones_solid = 'headphones_solid.svg';
  static const String headset_outline = 'headset_outline.svg';
  static const String headset_solid = 'headset_solid.svg';
  static const String heart_circle_outline = 'heart_circle_outline.svg';
  static const String heart_circle_solid = 'heart_circle_solid.svg';
  static const String heart_outline = 'heart_outline.svg';
  static const String heart_small_outline = 'heart_small_outline.svg';
  static const String heart_small_solid = 'heart_small_solid.svg';
  static const String heart_solid = 'heart_solid.svg';
  static const String hexagon_outline = 'hexagon_outline.svg';
  static const String hexagon_solid = 'hexagon_solid.svg';
  static const String history_outline = 'history_outline.svg';
  static const String history_solid = 'history_solid.svg';
  static const String home_alt_outline = 'home_alt_outline.svg';
  static const String home_alt_solid = 'home_alt_solid.svg';
  static const String home_outline = 'home_outline.svg';
  static const String home_solid = 'home_solid.svg';
  static const String hospital_outline = 'hospital_outline.svg';
  static const String hospital_solid = 'hospital_solid.svg';
  static const String hourglass_outline = 'hourglass_outline.svg';
  static const String hourglass_solid = 'hourglass_solid.svg';
  static const String house_outline = 'house_outline.svg';
  static const String house_solid = 'house_solid.svg';
  static const String html5_outline = 'html5_outline.svg';
  static const String html5_solid = 'html5_solid.svg';
  static const String id_outline = 'id_outline.svg';
  static const String id_solid = 'id_solid.svg';
  static const String imac_outline = 'imac_outline.svg';
  static const String imac_solid = 'imac_solid.svg';
  static const String image_alt_outline = 'image_alt_outline.svg';
  static const String image_alt_solid = 'image_alt_solid.svg';
  static const String image_document_outline = 'image_document_outline.svg';
  static const String image_document_solid = 'image_document_solid.svg';
  static const String image_outline = 'image_outline.svg';
  static const String image_solid = 'image_solid.svg';
  static const String in_ear_headphones_outline = 'in_ear_headphones_outline.svg';
  static const String in_ear_headphones_solid = 'in_ear_headphones_solid.svg';
  static const String inbox_outline = 'inbox_outline.svg';
  static const String inbox_solid = 'inbox_solid.svg';
  static const String indent_decrease_outline = 'indent_decrease_outline.svg';
  static const String indent_decrease_solid = 'indent_decrease_solid.svg';
  static const String indent_increase_outline = 'indent_increase_outline.svg';
  static const String indent_increase_solid = 'indent_increase_solid.svg';
  static const String info_circle_outline = 'info_circle_outline.svg';
  static const String info_circle_solid = 'info_circle_solid.svg';
  static const String info_outline = 'info_outline.svg';
  static const String info_small_outline = 'info_small_outline.svg';
  static const String info_small_solid = 'info_small_solid.svg';
  static const String info_solid = 'info_solid.svg';
  static const String instagram_outline = 'instagram_outline.svg';
  static const String instagram_solid = 'instagram_solid.svg';
  static const String invoice_outline = 'invoice_outline.svg';
  static const String invoice_solid = 'invoice_solid.svg';
  static const String italic_outline = 'italic_outline.svg';
  static const String italic_solid = 'italic_solid.svg';
  static const String javascript_outline = 'javascript_outline.svg';
  static const String javascript_solid = 'javascript_solid.svg';
  static const String joystick_outline = 'joystick_outline.svg';
  static const String joystick_solid = 'joystick_solid.svg';
  static const String jpg_outline = 'jpg_outline.svg';
  static const String jpg_solid = 'jpg_solid.svg';
  static const String kanban_outline = 'kanban_outline.svg';
  static const String kanban_solid = 'kanban_solid.svg';
  static const String key_outline = 'key_outline.svg';
  static const String key_solid = 'key_solid.svg';
  static const String keyboard_outline = 'keyboard_outline.svg';
  static const String keyboard_solid = 'keyboard_solid.svg';
  static const String lan_cable_outline = 'lan_cable_outline.svg';
  static const String lan_cable_solid = 'lan_cable_solid.svg';
  static const String laptop_outline = 'laptop_outline.svg';
  static const String laptop_solid = 'laptop_solid.svg';
  static const String laravel_outline = 'laravel_outline.svg';
  static const String laravel_solid = 'laravel_solid.svg';
  static const String layers_difference_outline = 'layers_difference_outline.svg';
  static const String layers_difference_solid = 'layers_difference_solid.svg';
  static const String layers_intersect_outline = 'layers_intersect_outline.svg';
  static const String layers_intersect_solid = 'layers_intersect_solid.svg';
  static const String layers_outline = 'layers_outline.svg';
  static const String layers_solid = 'layers_solid.svg';
  static const String layers_subtract_outline = 'layers_subtract_outline.svg';
  static const String layers_subtract_solid = 'layers_subtract_solid.svg';
  static const String layers_union_outline = 'layers_union_outline.svg';
  static const String layers_union_solid = 'layers_union_solid.svg';
  static const String left_circle_outline = 'left_circle_outline.svg';
  static const String left_circle_solid = 'left_circle_solid.svg';
  static const String left_outline = 'left_outline.svg';
  static const String left_small_outline = 'left_small_outline.svg';
  static const String left_small_solid = 'left_small_solid.svg';
  static const String left_solid = 'left_solid.svg';
  static const String lego_outline = 'lego_outline.svg';
  static const String lego_solid = 'lego_solid.svg';
  static const String lifebuoy_outline = 'lifebuoy_outline.svg';
  static const String lifebuoy_solid = 'lifebuoy_solid.svg';
  static const String lightning_cable_outline = 'lightning_cable_outline.svg';
  static const String lightning_cable_solid = 'lightning_cable_solid.svg';
  static const String line_outline = 'line_outline.svg';
  static const String line_solid = 'line_solid.svg';
  static const String link_outline = 'link_outline.svg';
  static const String link_remove_outline = 'link_remove_outline.svg';
  static const String link_remove_solid = 'link_remove_solid.svg';
  static const String link_solid = 'link_solid.svg';
  static const String linkedin_outline = 'linkedin_outline.svg';
  static const String linkedin_solid = 'linkedin_solid.svg';
  static const String linux_alt_outline = 'linux_alt_outline.svg';
  static const String linux_alt_solid = 'linux_alt_solid.svg';
  static const String linux_outline = 'linux_outline.svg';
  static const String linux_solid = 'linux_solid.svg';
  static const String list_layout_outline = 'list_layout_outline.svg';
  static const String list_layout_solid = 'list_layout_solid.svg';
  static const String list_ordered_outline = 'list_ordered_outline.svg';
  static const String list_ordered_solid = 'list_ordered_solid.svg';
  static const String list_unordered_outline = 'list_unordered_outline.svg';
  static const String list_unordered_solid = 'list_unordered_solid.svg';
  static const String litecoin_outline = 'litecoin_outline.svg';
  static const String litecoin_solid = 'litecoin_solid.svg';
  static const String loader_outline = 'loader_outline.svg';
  static const String loader_solid = 'loader_solid.svg';
  static const String location_outline = 'location_outline.svg';
  static const String location_solid = 'location_solid.svg';
  static const String lock_circle_outline = 'lock_circle_outline.svg';
  static const String lock_circle_solid = 'lock_circle_solid.svg';
  static const String lock_outline = 'lock_outline.svg';
  static const String lock_small_outline = 'lock_small_outline.svg';
  static const String lock_small_solid = 'lock_small_solid.svg';
  static const String lock_solid = 'lock_solid.svg';
  static const String logout_outline = 'logout_outline.svg';
  static const String logout_solid = 'logout_solid.svg';
  static const String loop_outline = 'loop_outline.svg';
  static const String loop_solid = 'loop_solid.svg';
  static const String magsafe_outline = 'magsafe_outline.svg';
  static const String magsafe_solid = 'magsafe_solid.svg';
  static const String markdown_outline = 'markdown_outline.svg';
  static const String markdown_solid = 'markdown_solid.svg';
  static const String medium_outline = 'medium_outline.svg';
  static const String medium_solid = 'medium_solid.svg';
  static const String menu_outline = 'menu_outline.svg';
  static const String menu_solid = 'menu_solid.svg';
  static const String message_minus_outline = 'message_minus_outline.svg';
  static const String message_minus_solid = 'message_minus_solid.svg';
  static const String message_no_access_outline = 'message_no_access_outline.svg';
  static const String message_no_access_solid = 'message_no_access_solid.svg';
  static const String message_outline = 'message_outline.svg';
  static const String message_plus_outline = 'message_plus_outline.svg';
  static const String message_plus_solid = 'message_plus_solid.svg';
  static const String message_solid = 'message_solid.svg';
  static const String message_text_alt_outline = 'message_text_alt_outline.svg';
  static const String message_text_alt_solid = 'message_text_alt_solid.svg';
  static const String message_text_outline = 'message_text_outline.svg';
  static const String message_text_solid = 'message_text_solid.svg';
  static const String message_tick_outline = 'message_tick_outline.svg';
  static const String message_tick_solid = 'message_tick_solid.svg';
  static const String message_x_outline = 'message_x_outline.svg';
  static const String message_x_solid = 'message_x_solid.svg';
  static const String messenger_outline = 'messenger_outline.svg';
  static const String messenger_solid = 'messenger_solid.svg';
  static const String micro_sd_card_outline = 'micro_sd_card_outline.svg';
  static const String micro_sd_card_solid = 'micro_sd_card_solid.svg';
  static const String microphone_outline = 'microphone_outline.svg';
  static const String microphone_solid = 'microphone_solid.svg';
  static const String minimise_alt_outline = 'minimise_alt_outline.svg';
  static const String minimise_alt_solid = 'minimise_alt_solid.svg';
  static const String minimise_outline = 'minimise_outline.svg';
  static const String minimise_solid = 'minimise_solid.svg';
  static const String minus_circle_outline = 'minus_circle_outline.svg';
  static const String minus_circle_solid = 'minus_circle_solid.svg';
  static const String minus_outline = 'minus_outline.svg';
  static const String minus_small_outline = 'minus_small_outline.svg';
  static const String minus_small_solid = 'minus_small_solid.svg';
  static const String minus_solid = 'minus_solid.svg';
  static const String mobile_outline = 'mobile_outline.svg';
  static const String mobile_solid = 'mobile_solid.svg';
  static const String money_outline = 'money_outline.svg';
  static const String money_solid = 'money_solid.svg';
  static const String money_stack_outline = 'money_stack_outline.svg';
  static const String money_stack_solid = 'money_stack_solid.svg';
  static const String mongodb_outline = 'mongodb_outline.svg';
  static const String mongodb_solid = 'mongodb_solid.svg';
  static const String mood_flat_outline = 'mood_flat_outline.svg';
  static const String mood_flat_solid = 'mood_flat_solid.svg';
  static const String mood_frown_outline = 'mood_frown_outline.svg';
  static const String mood_frown_solid = 'mood_frown_solid.svg';
  static const String mood_laugh_outline = 'mood_laugh_outline.svg';
  static const String mood_laugh_solid = 'mood_laugh_solid.svg';
  static const String mood_sad_outline = 'mood_sad_outline.svg';
  static const String mood_sad_solid = 'mood_sad_solid.svg';
  static const String mood_smile_outline = 'mood_smile_outline.svg';
  static const String mood_smile_solid = 'mood_smile_solid.svg';
  static const String mood_surprised_outline = 'mood_surprised_outline.svg';
  static const String mood_surprised_solid = 'mood_surprised_solid.svg';
  static const String mood_tongue_outline = 'mood_tongue_outline.svg';
  static const String mood_tongue_solid = 'mood_tongue_solid.svg';
  static const String moon_outline = 'moon_outline.svg';
  static const String moon_solid = 'moon_solid.svg';
  static const String more_horizontal_outline = 'more_horizontal_outline.svg';
  static const String more_horizontal_solid = 'more_horizontal_solid.svg';
  static const String more_vertical_outline = 'more_vertical_outline.svg';
  static const String more_vertical_solid = 'more_vertical_solid.svg';
  static const String mouse_outline = 'mouse_outline.svg';
  static const String mouse_solid = 'mouse_solid.svg';
  static const String mov_outline = 'mov_outline.svg';
  static const String mov_solid = 'mov_solid.svg';
  static const String mp3_outline = 'mp3_outline.svg';
  static const String mp3_solid = 'mp3_solid.svg';
  static const String mp4_outline = 'mp4_outline.svg';
  static const String mp4_solid = 'mp4_solid.svg';
  static const String ms_excel_outline = 'ms_excel_outline.svg';
  static const String ms_excel_solid = 'ms_excel_solid.svg';
  static const String ms_powerpoint_outline = 'ms_powerpoint_outline.svg';
  static const String ms_powerpoint_solid = 'ms_powerpoint_solid.svg';
  static const String ms_word_outline = 'ms_word_outline.svg';
  static const String ms_word_solid = 'ms_word_solid.svg';
  static const String n64_outline = 'n64_outline.svg';
  static const String n64_solid = 'n64_solid.svg';
  static const String nes_outline = 'nes_outline.svg';
  static const String nes_solid = 'nes_solid.svg';
  static const String netlify_outline = 'netlify_outline.svg';
  static const String netlify_solid = 'netlify_solid.svg';
  static const String next_circle_outline = 'next_circle_outline.svg';
  static const String next_circle_solid = 'next_circle_solid.svg';
  static const String next_outline = 'next_outline.svg';
  static const String next_small_outline = 'next_small_outline.svg';
  static const String next_small_solid = 'next_small_solid.svg';
  static const String next_solid = 'next_solid.svg';
  static const String nextjs_outline = 'nextjs_outline.svg';
  static const String nextjs_solid = 'nextjs_solid.svg';
  static const String ngc_outline = 'ngc_outline.svg';
  static const String ngc_solid = 'ngc_solid.svg';
  static const String nintendo_switch_outline = 'nintendo_switch_outline.svg';
  static const String nintendo_switch_solid = 'nintendo_switch_solid.svg';
  static const String nodejs_outline = 'nodejs_outline.svg';
  static const String nodejs_solid = 'nodejs_solid.svg';
  static const String note_outline = 'note_outline.svg';
  static const String note_solid = 'note_solid.svg';
  static const String npm_outline = 'npm_outline.svg';
  static const String npm_solid = 'npm_solid.svg';
  static const String nuxtjs_outline = 'nuxtjs_outline.svg';
  static const String nuxtjs_solid = 'nuxtjs_solid.svg';
  static const String omega_outline = 'omega_outline.svg';
  static const String omega_solid = 'omega_solid.svg';
  static const String opera_outline = 'opera_outline.svg';
  static const String opera_solid = 'opera_solid.svg';
  static const String otp_outline = 'otp_outline.svg';
  static const String otp_solid = 'otp_solid.svg';
  static const String page_break_outline = 'page_break_outline.svg';
  static const String page_break_solid = 'page_break_solid.svg';
  static const String page_number_outline = 'page_number_outline.svg';
  static const String page_number_solid = 'page_number_solid.svg';
  static const String paintbrush_outline = 'paintbrush_outline.svg';
  static const String paintbrush_solid = 'paintbrush_solid.svg';
  static const String paintbucket_outline = 'paintbucket_outline.svg';
  static const String paintbucket_solid = 'paintbucket_solid.svg';
  static const String paragraph_outline = 'paragraph_outline.svg';
  static const String paragraph_solid = 'paragraph_solid.svg';
  static const String password_outline = 'password_outline.svg';
  static const String password_solid = 'password_solid.svg';
  static const String patreon_outline = 'patreon_outline.svg';
  static const String patreon_solid = 'patreon_solid.svg';
  static const String pause_circle_outline = 'pause_circle_outline.svg';
  static const String pause_circle_solid = 'pause_circle_solid.svg';
  static const String pause_outline = 'pause_outline.svg';
  static const String pause_small_outline = 'pause_small_outline.svg';
  static const String pause_small_solid = 'pause_small_solid.svg';
  static const String pause_solid = 'pause_solid.svg';
  static const String paw_outline = 'paw_outline.svg';
  static const String paw_solid = 'paw_solid.svg';
  static const String paws_outline = 'paws_outline.svg';
  static const String paws_solid = 'paws_solid.svg';
  static const String paypal_outline = 'paypal_outline.svg';
  static const String paypal_solid = 'paypal_solid.svg';
  static const String pdf_outline = 'pdf_outline.svg';
  static const String pdf_solid = 'pdf_solid.svg';
  static const String pen_outline = 'pen_outline.svg';
  static const String pen_solid = 'pen_solid.svg';
  static const String phone_outline = 'phone_outline.svg';
  static const String phone_solid = 'phone_solid.svg';
  static const String phonecall_blocked_outline = 'phonecall_blocked_outline.svg';
  static const String phonecall_blocked_solid = 'phonecall_blocked_solid.svg';
  static const String phonecall_outline = 'phonecall_outline.svg';
  static const String phonecall_receive_outline = 'phonecall_receive_outline.svg';
  static const String phonecall_receive_solid = 'phonecall_receive_solid.svg';
  static const String phonecall_solid = 'phonecall_solid.svg';
  static const String pie_chart_alt_outline = 'pie_chart_alt_outline.svg';
  static const String pie_chart_alt_solid = 'pie_chart_alt_solid.svg';
  static const String pie_chart_outline = 'pie_chart_outline.svg';
  static const String pie_chart_solid = 'pie_chart_solid.svg';
  static const String pin_alt_outline = 'pin_alt_outline.svg';
  static const String pin_alt_solid = 'pin_alt_solid.svg';
  static const String pin_outline = 'pin_outline.svg';
  static const String pin_solid = 'pin_solid.svg';
  static const String pinterest_outline = 'pinterest_outline.svg';
  static const String pinterest_solid = 'pinterest_solid.svg';
  static const String plant_outline = 'plant_outline.svg';
  static const String plant_solid = 'plant_solid.svg';
  static const String play_circle_outline = 'play_circle_outline.svg';
  static const String play_circle_solid = 'play_circle_solid.svg';
  static const String play_outline = 'play_outline.svg';
  static const String play_small_outline = 'play_small_outline.svg';
  static const String play_small_solid = 'play_small_solid.svg';
  static const String play_solid = 'play_solid.svg';
  static const String plug_outline = 'plug_outline.svg';
  static const String plug_solid = 'plug_solid.svg';
  static const String plus_circle_outline = 'plus_circle_outline.svg';
  static const String plus_circle_solid = 'plus_circle_solid.svg';
  static const String png_outline = 'png_outline.svg';
  static const String png_solid = 'png_solid.svg';
  static const String pool_outline = 'pool_outline.svg';
  static const String pool_solid = 'pool_solid.svg';
  static const String pound_outline = 'pound_outline.svg';
  static const String pound_solid = 'pound_solid.svg';
  static const String power_outline = 'power_outline.svg';
  static const String power_solid = 'power_solid.svg';
  static const String ppt_outline = 'ppt_outline.svg';
  static const String ppt_solid = 'ppt_solid.svg';
  static const String print_outline = 'print_outline.svg';
  static const String print_solid = 'print_solid.svg';
  static const String python_outline = 'python_outline.svg';
  static const String python_solid = 'python_solid.svg';
  static const String qr_code_outline = 'qr_code_outline.svg';
  static const String qr_code_solid = 'qr_code_solid.svg';
  static const String question_circle_outline = 'question_circle_outline.svg';
  static const String question_circle_solid = 'question_circle_solid.svg';
  static const String question_outline = 'question_outline.svg';
  static const String question_small_outline = 'question_small_outline.svg';
  static const String question_small_solid = 'question_small_solid.svg';
  static const String question_solid = 'question_solid.svg';
  static const String quote_outline = 'quote_outline.svg';
  static const String quote_solid = 'quote_solid.svg';
  static const String rand_outline = 'rand_outline.svg';
  static const String rand_solid = 'rand_solid.svg';
  static const String react_outline = 'react_outline.svg';
  static const String react_solid = 'react_solid.svg';
  static const String receipt_outline = 'receipt_outline.svg';
  static const String receipt_solid = 'receipt_solid.svg';
  static const String reddit_outline = 'reddit_outline.svg';
  static const String reddit_solid = 'reddit_solid.svg';
  static const String redwoodjs_outline = 'redwoodjs_outline.svg';
  static const String redwoodjs_solid = 'redwoodjs_solid.svg';
  static const String refresh_alt_outline = 'refresh_alt_outline.svg';
  static const String refresh_alt_solid = 'refresh_alt_solid.svg';
  static const String refresh_outline = 'refresh_outline.svg';
  static const String refresh_solid = 'refresh_solid.svg';
  static const String rewind_circle_outline = 'rewind_circle_outline.svg';
  static const String rewind_circle_solid = 'rewind_circle_solid.svg';
  static const String rewind_outline = 'rewind_outline.svg';
  static const String rewind_small_outline = 'rewind_small_outline.svg';
  static const String rewind_small_solid = 'rewind_small_solid.svg';
  static const String rewind_solid = 'rewind_solid.svg';
  static const String right_circle_outline = 'right_circle_outline.svg';
  static const String right_circle_solid = 'right_circle_solid.svg';
  static const String right_outline = 'right_outline.svg';
  static const String right_small_outline = 'right_small_outline.svg';
  static const String right_small_solid = 'right_small_solid.svg';
  static const String right_solid = 'right_solid.svg';
  static const String ripple_outline = 'ripple_outline.svg';
  static const String ripple_solid = 'ripple_solid.svg';
  static const String robot_outline = 'robot_outline.svg';
  static const String robot_solid = 'robot_solid.svg';
  static const String roller_outline = 'roller_outline.svg';
  static const String roller_solid = 'roller_solid.svg';
  static const String rollupjs_outline = 'rollupjs_outline.svg';
  static const String rollupjs_solid = 'rollupjs_solid.svg';
  static const String router_outline = 'router_outline.svg';
  static const String router_solid = 'router_solid.svg';
  static const String rss_outline = 'rss_outline.svg';
  static const String rss_solid = 'rss_solid.svg';
  static const String ruby_outline = 'ruby_outline.svg';
  static const String ruby_solid = 'ruby_solid.svg';
  static const String rupee_outline = 'rupee_outline.svg';
  static const String rupee_solid = 'rupee_solid.svg';
  static const String rust_outline = 'rust_outline.svg';
  static const String rust_solid = 'rust_solid.svg';
  static const String safari_outline = 'safari_outline.svg';
  static const String safari_solid = 'safari_solid.svg';
  static const String safe_outline = 'safe_outline.svg';
  static const String safe_solid = 'safe_solid.svg';
  static const String save_outline = 'save_outline.svg';
  static const String save_solid = 'save_solid.svg';
  static const String scan_outline = 'scan_outline.svg';
  static const String scan_solid = 'scan_solid.svg';
  static const String school_outline = 'school_outline.svg';
  static const String school_solid = 'school_solid.svg';
  static const String screen_alt_2_outline = 'screen_alt_2_outline.svg';
  static const String screen_alt_2_solid = 'screen_alt_2_solid.svg';
  static const String screen_alt_outline = 'screen_alt_outline.svg';
  static const String screen_alt_solid = 'screen_alt_solid.svg';
  static const String screen_outline = 'screen_outline.svg';
  static const String screen_solid = 'screen_solid.svg';
  static const String scribble_outline = 'scribble_outline.svg';
  static const String scribble_solid = 'scribble_solid.svg';
  static const String sd_card_outline = 'sd_card_outline.svg';
  static const String sd_card_solid = 'sd_card_solid.svg';
  static const String search_circle_outline = 'search_circle_outline.svg';
  static const String search_circle_solid = 'search_circle_solid.svg';
  static const String search_outline = 'search_outline.svg';
  static const String search_property_outline = 'search_property_outline.svg';
  static const String search_property_solid = 'search_property_solid.svg';
  static const String search_small_outline = 'search_small_outline.svg';
  static const String search_small_solid = 'search_small_solid.svg';
  static const String search_solid = 'search_solid.svg';
  static const String section_add_outline = 'section_add_outline.svg';
  static const String section_add_solid = 'section_add_solid.svg';
  static const String section_remove_outline = 'section_remove_outline.svg';
  static const String section_remove_solid = 'section_remove_solid.svg';
  static const String send_down_outline = 'send_down_outline.svg';
  static const String send_down_solid = 'send_down_solid.svg';
  static const String send_left_outline = 'send_left_outline.svg';
  static const String send_left_solid = 'send_left_solid.svg';
  static const String send_outline = 'send_outline.svg';
  static const String send_right_outline = 'send_right_outline.svg';
  static const String send_right_solid = 'send_right_solid.svg';
  static const String send_solid = 'send_solid.svg';
  static const String send_up_outline = 'send_up_outline.svg';
  static const String send_up_solid = 'send_up_solid.svg';
  static const String servers_outline = 'servers_outline.svg';
  static const String servers_solid = 'servers_solid.svg';
  static const String share_outline = 'share_outline.svg';
  static const String share_solid = 'share_solid.svg';
  static const String shield_outline = 'shield_outline.svg';
  static const String shield_solid = 'shield_solid.svg';
  static const String shield_tick_outline = 'shield_tick_outline.svg';
  static const String shield_tick_solid = 'shield_tick_solid.svg';
  static const String shield_x_outline = 'shield_x_outline.svg';
  static const String shield_x_solid = 'shield_x_solid.svg';
  static const String shop_outline = 'shop_outline.svg';
  static const String shop_solid = 'shop_solid.svg';
  static const String sign_outline = 'sign_outline.svg';
  static const String sign_solid = 'sign_solid.svg';
  static const String signin_outline = 'signin_outline.svg';
  static const String signin_solid = 'signin_solid.svg';
  static const String sim_outline = 'sim_outline.svg';
  static const String sim_solid = 'sim_solid.svg';
  static const String simohamed_outline = 'simohamed_outline.svg';
  static const String simohamed_solid = 'simohamed_solid.svg';
  static const String skull_outline = 'skull_outline.svg';
  static const String skull_solid = 'skull_solid.svg';
  static const String skype_outline = 'skype_outline.svg';
  static const String skype_solid = 'skype_solid.svg';
  static const String slack_outline = 'slack_outline.svg';
  static const String slack_solid = 'slack_solid.svg';
  static const String snapchat_outline = 'snapchat_outline.svg';
  static const String snapchat_solid = 'snapchat_solid.svg';
  static const String snes_outline = 'snes_outline.svg';
  static const String snes_solid = 'snes_solid.svg';
  static const String sort_alphabetically_outline = 'sort_alphabetically_outline.svg';
  static const String sort_alphabetically_solid = 'sort_alphabetically_solid.svg';
  static const String sort_down_outline = 'sort_down_outline.svg';
  static const String sort_down_solid = 'sort_down_solid.svg';
  static const String sort_high_to_low_outline = 'sort_high_to_low_outline.svg';
  static const String sort_high_to_low_solid = 'sort_high_to_low_solid.svg';
  static const String sort_low_to_high_outline = 'sort_low_to_high_outline.svg';
  static const String sort_low_to_high_solid = 'sort_low_to_high_solid.svg';
  static const String sort_reverse_alphabetically_outline = 'sort_reverse_alphabetically_outline.svg';
  static const String sort_reverse_alphabetically_solid = 'sort_reverse_alphabetically_solid.svg';
  static const String sort_up_outline = 'sort_up_outline.svg';
  static const String sort_up_solid = 'sort_up_solid.svg';
  static const String sound_off_outline = 'sound_off_outline.svg';
  static const String sound_off_solid = 'sound_off_solid.svg';
  static const String sound_on_outline = 'sound_on_outline.svg';
  static const String sound_on_solid = 'sound_on_solid.svg';
  static const String spotify_outline = 'spotify_outline.svg';
  static const String spotify_solid = 'spotify_solid.svg';
  static const String spreadsheet_outline = 'spreadsheet_outline.svg';
  static const String spreadsheet_solid = 'spreadsheet_solid.svg';
  static const String square_outline = 'square_outline.svg';
  static const String square_solid = 'square_solid.svg';
  static const String stackoverflow_outline = 'stackoverflow_outline.svg';
  static const String stackoverflow_solid = 'stackoverflow_solid.svg';
  static const String stamp_outline = 'stamp_outline.svg';
  static const String stamp_solid = 'stamp_solid.svg';
  static const String star_circle_outline = 'star_circle_outline.svg';
  static const String star_circle_solid = 'star_circle_solid.svg';
  static const String star_outline = 'star_outline.svg';
  static const String star_small_outline = 'star_small_outline.svg';
  static const String star_small_solid = 'star_small_solid.svg';
  static const String star_solid = 'star_solid.svg';
  static const String stop_circle_outline = 'stop_circle_outline.svg';
  static const String stop_circle_solid = 'stop_circle_solid.svg';
  static const String stop_outline = 'stop_outline.svg';
  static const String stop_small_outline = 'stop_small_outline.svg';
  static const String stop_small_solid = 'stop_small_solid.svg';
  static const String stop_solid = 'stop_solid.svg';
  static const String stopwatch_outline = 'stopwatch_outline.svg';
  static const String stopwatch_solid = 'stopwatch_solid.svg';
  static const String strikethrough_outline = 'strikethrough_outline.svg';
  static const String strikethrough_solid = 'strikethrough_solid.svg';
  static const String subscript_outline = 'subscript_outline.svg';
  static const String subscript_solid = 'subscript_solid.svg';
  static const String sun_outline = 'sun_outline.svg';
  static const String sun_solid = 'sun_solid.svg';
  static const String superscript_outline = 'superscript_outline.svg';
  static const String superscript_solid = 'superscript_solid.svg';
  static const String svelte_outline = 'svelte_outline.svg';
  static const String svelte_solid = 'svelte_solid.svg';
  static const String svg_outline = 'svg_outline.svg';
  static const String svg_solid = 'svg_solid.svg';
  static const String table_outline = 'table_outline.svg';
  static const String table_solid = 'table_solid.svg';
  static const String tablet_outline = 'tablet_outline.svg';
  static const String tablet_solid = 'tablet_solid.svg';
  static const String tag_outline = 'tag_outline.svg';
  static const String tag_solid = 'tag_solid.svg';
  static const String tailwind_outline = 'tailwind_outline.svg';
  static const String tailwind_solid = 'tailwind_solid.svg';
  static const String target_outline = 'target_outline.svg';
  static const String target_solid = 'target_solid.svg';
  static const String telegram_outline = 'telegram_outline.svg';
  static const String telegram_solid = 'telegram_solid.svg';
  static const String terminal_outline = 'terminal_outline.svg';
  static const String terminal_solid = 'terminal_solid.svg';
  static const String text_document_alt_outline = 'text_document_alt_outline.svg';
  static const String text_document_alt_solid = 'text_document_alt_solid.svg';
  static const String text_document_outline = 'text_document_outline.svg';
  static const String text_document_solid = 'text_document_solid.svg';
  static const String text_outline = 'text_outline.svg';
  static const String text_solid = 'text_solid.svg';
  static const String thumb_down_outline = 'thumb_down_outline.svg';
  static const String thumb_down_solid = 'thumb_down_solid.svg';
  static const String thumb_up_outline = 'thumb_up_outline.svg';
  static const String thumb_up_solid = 'thumb_up_solid.svg';
  static const String thumbtack_outline = 'thumbtack_outline.svg';
  static const String thumbtack_solid = 'thumbtack_solid.svg';
  static const String tick_circle_outline = 'tick_circle_outline.svg';
  static const String tick_circle_solid = 'tick_circle_solid.svg';
  static const String tick_outline = 'tick_outline.svg';
  static const String tick_small_outline = 'tick_small_outline.svg';
  static const String tick_small_solid = 'tick_small_solid.svg';
  static const String tick_solid = 'tick_solid.svg';
  static const String tiktok_outline = 'tiktok_outline.svg';
  static const String tiktok_solid = 'tiktok_solid.svg';
  static const String toggle_outline = 'toggle_outline.svg';
  static const String toggle_solid = 'toggle_solid.svg';
  static const String top_left_outline = 'top_left_outline.svg';
  static const String top_left_solid = 'top_left_solid.svg';
  static const String top_right_outline = 'top_right_outline.svg';
  static const String top_right_solid = 'top_right_solid.svg';
  static const String trend_down_outline = 'trend_down_outline.svg';
  static const String trend_down_solid = 'trend_down_solid.svg';
  static const String trend_up_outline = 'trend_up_outline.svg';
  static const String trend_up_solid = 'trend_up_solid.svg';
  static const String triangle_outline = 'triangle_outline.svg';
  static const String triangle_solid = 'triangle_solid.svg';
  static const String trophy_outline = 'trophy_outline.svg';
  static const String trophy_solid = 'trophy_solid.svg';
  static const String tv_outline = 'tv_outline.svg';
  static const String tv_solid = 'tv_solid.svg';
  static const String twitch_outline = 'twitch_outline.svg';
  static const String twitch_solid = 'twitch_solid.svg';
  static const String twitter_outline = 'twitter_outline.svg';
  static const String twitter_solid = 'twitter_solid.svg';
  static const String typescript_outline = 'typescript_outline.svg';
  static const String typescript_solid = 'typescript_solid.svg';
  static const String underline_outline = 'underline_outline.svg';
  static const String underline_solid = 'underline_solid.svg';
  static const String unlock_circle_outline = 'unlock_circle_outline.svg';
  static const String unlock_circle_solid = 'unlock_circle_solid.svg';
  static const String unlock_outline = 'unlock_outline.svg';
  static const String unlock_small_outline = 'unlock_small_outline.svg';
  static const String unlock_small_solid = 'unlock_small_solid.svg';
  static const String unlock_solid = 'unlock_solid.svg';
  static const String up_circle_outline = 'up_circle_outline.svg';
  static const String up_circle_solid = 'up_circle_solid.svg';
  static const String up_outline = 'up_outline.svg';
  static const String up_small_outline = 'up_small_outline.svg';
  static const String up_small_solid = 'up_small_solid.svg';
  static const String up_solid = 'up_solid.svg';
  static const String upload_outline = 'upload_outline.svg';
  static const String upload_solid = 'upload_solid.svg';
  static const String usb_cable_outline = 'usb_cable_outline.svg';
  static const String usb_cable_solid = 'usb_cable_solid.svg';
  static const String user_circle_outline = 'user_circle_outline.svg';
  static const String user_circle_solid = 'user_circle_solid.svg';
  static const String user_minus_outline = 'user_minus_outline.svg';
  static const String user_minus_solid = 'user_minus_solid.svg';
  static const String user_outline = 'user_outline.svg';
  static const String user_plus_outline = 'user_plus_outline.svg';
  static const String user_plus_solid = 'user_plus_solid.svg';
  static const String user_solid = 'user_solid.svg';
  static const String user_square_outline = 'user_square_outline.svg';
  static const String user_square_solid = 'user_square_solid.svg';
  static const String users_outline = 'users_outline.svg';
  static const String users_solid = 'users_solid.svg';
  static const String vector_document_outline = 'vector_document_outline.svg';
  static const String vector_document_solid = 'vector_document_solid.svg';
  static const String venn_diagram_outline = 'venn_diagram_outline.svg';
  static const String venn_diagram_solid = 'venn_diagram_solid.svg';
  static const String view_column_outline = 'view_column_outline.svg';
  static const String view_column_solid = 'view_column_solid.svg';
  static const String view_grid_outline = 'view_grid_outline.svg';
  static const String view_grid_solid = 'view_grid_solid.svg';
  static const String vim_outline = 'vim_outline.svg';
  static const String vim_solid = 'vim_solid.svg';
  static const String volume_1_outline = 'volume_1_outline.svg';
  static const String volume_1_solid = 'volume_1_solid.svg';
  static const String volume_2_outline = 'volume_2_outline.svg';
  static const String volume_3_outline = 'volume_3_outline.svg';
  static const String volume_3_solid = 'volume_3_solid.svg';
  static const String vr_headset_outline = 'vr_headset_outline.svg';
  static const String vue_outline = 'vue_outline.svg';
  static const String vue_solid = 'vue_solid.svg';
  static const String wallet_alt_outline = 'wallet_alt_outline.svg';
  static const String wallet_alt_solid = 'wallet_alt_solid.svg';
  static const String wallet_outline = 'wallet_outline.svg';
  static const String wallet_solid = 'wallet_solid.svg';
  static const String wan_outline = 'wan_outline.svg';
  static const String wan_solid = 'wan_solid.svg';
  static const String wand_outline = 'wand_outline.svg';
  static const String wand_solid = 'wand_solid.svg';
  static const String watch_outline = 'watch_outline.svg';
  static const String watch_solid = 'watch_solid.svg';
  static const String webpack_outline = 'webpack_outline.svg';
  static const String webpack_solid = 'webpack_solid.svg';
  static const String whatsapp_outline = 'whatsapp_outline.svg';
  static const String whatsapp_solid = 'whatsapp_solid.svg';
  static const String wifi_full_outline = 'wifi_full_outline.svg';
  static const String wifi_full_solid = 'wifi_full_solid.svg';
  static const String wifi_low_outline = 'wifi_low_outline.svg';
  static const String wifi_low_solid = 'wifi_low_solid.svg';
  static const String wifi_none_outline = 'wifi_none_outline.svg';
  static const String wifi_none_solid = 'wifi_none_solid.svg';
  static const String windows_outline = 'windows_outline.svg';
  static const String windows_solid = 'windows_solid.svg';
  static const String wordpress_outline = 'wordpress_outline.svg';
  static const String wordpress_solid = 'wordpress_solid.svg';
  static const String x_circle_outline = 'x_circle_outline.svg';
  static const String x_circle_solid = 'x_circle_solid.svg';
  static const String x_outline = 'x_outline.svg';
  static const String x_small_outline = 'x_small_outline.svg';
  static const String x_small_solid = 'x_small_solid.svg';
  static const String x_solid = 'x_solid.svg';
  static const String xls_outline = 'xls_outline.svg';
  static const String xls_solid = 'xls_solid.svg';
  static const String yen_outline = 'yen_outline.svg';
  static const String yen_solid = 'yen_solid.svg';
  static const String youtube_outline = 'youtube_outline.svg';
  static const String youtube_solid = 'youtube_solid.svg';
  static const String zip_outline = 'zip_outline.svg';
  static const String zip_solid = 'zip_solid.svg';
  static const String zoom_in_outline = 'zoom_in_outline.svg';
  static const String zoom_in_solid = 'zoom_in_solid.svg';
  static const String zoom_out_outline = 'zoom_out_outline.svg';
  static const String zoom_out_solid = 'zoom_out_solid.svg';
}
